@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2021 Greenbone Networks GmbH
+# Copyright (C) 2021-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -17,3 +17,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from .changelog import add_skeleton, update, ChangelogError
+from .conventional_commits import main, ChangelogBuilder
+
+__all__ = [
+    'add_skeleton',
+    'update',
+    'ChangelogBuilder',
+    'ChangelogError',
+    'main',
+]
