@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # pontos/release/release.py
-# Copyright (C) 2020 - 2021 Greenbone Networks GmbH
+# Copyright (C) 2020-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -34,7 +34,7 @@ from pontos.terminal import error, warning, info, ok, out, overwrite
 from pontos.terminal.terminal import Signs
 from pontos.version.helper import VersionError
 from pontos.version import (
-    PontosVersionCommand,
+    PythonVersionCommand,
     CMakeVersionCommand,
 )
 
@@ -88,6 +88,7 @@ def commit_files(
     shell_cmd_runner: Callable,
     *,
     git_signing_key: str = '',
+    changelog: bool = False,
 ):
     """Add files to staged and commit staged files.
 
@@ -107,10 +108,11 @@ def commit_files(
 
     shell_cmd_runner(f"git add {filename}")
     shell_cmd_runner("git add *__version__.py || echo 'ignoring __version__'")
-    shell_cmd_runner("git add CHANGELOG.md")
+    if changelog:
+        shell_cmd_runner("git add CHANGELOG.md")
     if git_signing_key:
         shell_cmd_runner(
-            f"git commit -S {git_signing_key} --no-verify -m '{commit_msg}'",
+            f"git commit -S{git_signing_key} --no-verify -m '{commit_msg}'",
         )
     else:
         shell_cmd_runner(f"git commit --no-verify -m '{commit_msg}'")
@@ -249,7 +251,7 @@ def get_current_version() -> str:
 
     available_cmds = [
         ('CMakeLists.txt', CMakeVersionCommand),
-        ('pyproject.toml', PontosVersionCommand),
+        ('pyproject.toml', PythonVersionCommand),
     ]
     for file_name, cmd in available_cmds:
         project_definition_path = Path.cwd() / file_name
