@@ -1,4 +1,4 @@
-# Copyright (C) 2020-2021 Greenbone Networks GmbH
+# Copyright (C) 2020-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -14,26 +14,21 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 import sys
 from pathlib import Path
 from .__version__ import __version__
 
-from .version import (
-    PontosVersionCommand,
-    VersionCommand,
-    VersionError,
-    safe_version,
-    strip_version,
-    is_version_pep440_compliant,
-    get_version_from_pyproject_toml,
-)
-from .cmake_version import CMakeVersionParser, CMakeVersionCommand
+from .python import PythonVersionCommand
+from .cmake import CMakeVersionCommand
+from .go import GoVersionCommand
 
 
 def main(leave=True, args=None):
     available_cmds = [
         ('CMakeLists.txt', CMakeVersionCommand),
-        ('pyproject.toml', PontosVersionCommand),
+        ('pyproject.toml', PythonVersionCommand),
+        ('go.mod', GoVersionCommand),
     ]
     for file_name, cmd in available_cmds:
         project_definition_path = Path.cwd() / file_name
@@ -45,16 +40,3 @@ def main(leave=True, args=None):
     if leave:
         sys.exit("No command found")
     return False, ""
-
-
-__all__ = [
-    '__version__',
-    'CMakeVersionCommand',
-    'get_version_from_pyproject_toml',
-    'is_version_pep440_compliant',
-    'PontosVersionCommand',
-    'safe_version',
-    'strip_version',
-    'VersionCommand',
-    'VersionError',
-]
