@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2021 Greenbone Networks GmbH
+# Copyright (C) 2021-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -150,13 +150,13 @@ class TestHelperFunctions(unittest.TestCase):
             'name = "testrepo"\n'
             'version = "21.6.2.dev1"\n\n'
             '[tool.pontos.version]\n'
-            'version-module-file = "testrepo/__version__.py"\n'
+            'version-module-file = "testrepo/__version__.py"\n',
+            encoding='utf-8',
         )
         executed, filename = update_version(
             to='21.4.4', _version=version, develop=False
         )
-        toml_text = toml.read_text()
-        print(toml_text)
+        toml_text = toml.read_text(encoding='utf-8')
         self.assertEqual(filename, 'pyproject.toml')
         self.assertTrue(executed)
         self.assertEqual(
@@ -168,7 +168,7 @@ class TestHelperFunctions(unittest.TestCase):
             'version-module-file = "testrepo/__version__.py"\n',
         )
         self.assertTrue(version_file.exists())
-        version_text = version_file.read_text()
+        version_text = version_file.read_text(encoding='utf-8')
         self.assertEqual(
             version_text,
             '# pylint: disable=invalid-name\n\n'
@@ -191,18 +191,16 @@ class CalculateHelperVersionTestCase(unittest.TestCase):
 
         filenames = ['pyproject.toml', 'CMakeLists.txt']
         mocks = [
-            'pontos.release.helper.PontosVersionCommand',
+            'pontos.release.helper.PythonVersionCommand',
             'pontos.release.helper.CMakeVersionCommand',
         ]
         current_versions = [
-            '20.4.1.dev3',
-            f'{str(today.year % 100)}.4.1.dev3',
+            '21.4.1.dev3',
             f'19.{str(today.month)}.1.dev3',
             f'{str(today.year % 100)}.{str(today.month)}.1.dev3',
             f'{str(today.year % 100)}.{str(today.month)}.1',
         ]
         assert_versions = [
-            f'{str(today.year % 100)}.{str(today.month)}.0',
             f'{str(today.year % 100)}.{str(today.month)}.0',
             f'{str(today.year % 100)}.{str(today.month)}.0',
             f'{str(today.year % 100)}.{str(today.month)}.1',
@@ -225,7 +223,6 @@ class CalculateHelperVersionTestCase(unittest.TestCase):
                     )
 
                     release_version = calculate_calendar_version()
-
                     self.assertEqual(release_version, assert_version)
 
                 os.chdir('..')
@@ -261,7 +258,7 @@ class CalculateHelperVersionTestCase(unittest.TestCase):
 
         filenames = ['pyproject.toml', 'CMakeLists.txt']
         mocks = [
-            'pontos.release.helper.PontosVersionCommand',
+            'pontos.release.helper.PythonVersionCommand',
             'pontos.release.helper.CMakeVersionCommand',
         ]
         current_versions = [
