@@ -1,4 +1,4 @@
-# Copyright (C) 2020-2021 Greenbone Networks GmbH
+# Copyright (C) 2020-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -15,6 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import datetime
 import struct
 import re
 
@@ -298,8 +299,6 @@ class UpdateHeaderTestCase(TestCase):
         test_file = self.path / "test.py"
         test_file.touch()
 
-        # test_file.write_text(expected_header)
-
         code = update_file(file=test_file, regex=self.regex, args=self.args)
 
         ret = mock_stdout.getvalue()
@@ -308,7 +307,7 @@ class UpdateHeaderTestCase(TestCase):
             f"{test_file}: Added licence header.\n",
         )
         self.assertEqual(code, 0)
-        self.assertEqual(expected_header, test_file.read_text())
+        self.assertEqual(expected_header, test_file.read_text(encoding='utf-8'))
         test_file.unlink()
 
     @patch('sys.stdout', new_callable=StringIO)
@@ -340,7 +339,7 @@ class UpdateHeaderTestCase(TestCase):
         if test_file.exists():
             test_file.unlink()
 
-        test_file.write_text(header)
+        test_file.write_text(header, encoding='utf-8')
 
         code = update_file(file=test_file, regex=self.regex, args=self.args)
 
@@ -353,7 +352,7 @@ class UpdateHeaderTestCase(TestCase):
         )
         self.assertIn(
             '# Copyright (C) 2020-2021 Greenbone Networks GmbH',
-            test_file.read_text(),
+            test_file.read_text(encoding='utf-8'),
         )
 
         test_file.unlink()
@@ -387,7 +386,7 @@ class UpdateHeaderTestCase(TestCase):
         if test_file.exists():
             test_file.unlink()
 
-        test_file.write_text(header)
+        test_file.write_text(header, encoding='utf-8')
 
         code = update_file(file=test_file, regex=self.regex, args=self.args)
 
@@ -399,7 +398,7 @@ class UpdateHeaderTestCase(TestCase):
         )
         self.assertIn(
             '# Copyright (C) 2021 Greenbone Networks GmbH',
-            test_file.read_text(),
+            test_file.read_text(encoding='utf-8'),
         )
 
         test_file.unlink()
@@ -430,7 +429,7 @@ class UpdateHeaderTestCase(TestCase):
         self.assertEqual(args.company, self.args.company)
         self.assertEqual(args.directories, ['.'])
         self.assertTrue(args.changed)
-        self.assertEqual(args.year, '2021')
+        self.assertEqual(args.year, str(datetime.datetime.now().year))
         self.assertEqual(args.licence, self.args.licence)
 
     def test_get_exclude_list(self):
@@ -438,7 +437,7 @@ class UpdateHeaderTestCase(TestCase):
         test_dirname = Path(__file__) / "../.."
         # with a relative glob
         test_ignore_file = Path('ignore.file')
-        test_ignore_file.write_text("*.py\n")
+        test_ignore_file.write_text("*.py\n", encoding='utf-8')
 
         exclude_list = get_exclude_list(
             test_ignore_file, [test_dirname.resolve()]
