@@ -1,4 +1,4 @@
-# Copyright (C) 2020-2021 Greenbone Networks GmbH
+# Copyright (C) 2020-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -22,7 +22,7 @@ import unittest
 from pathlib import Path
 from unittest.mock import MagicMock
 
-from pontos.version import VersionCommand
+from pontos.version.python import PythonVersionCommand
 
 
 class UpdateVersionFileTestCase(unittest.TestCase):
@@ -30,7 +30,9 @@ class UpdateVersionFileTestCase(unittest.TestCase):
         fake_path_class = MagicMock(spec=Path)
         fake_path = fake_path_class.return_value
 
-        cmd = VersionCommand(version_file_path=fake_path)
+        fake_pyproject = Path(__file__).parent.parent / 'fake_pyproject.toml'
+        cmd = PythonVersionCommand(project_file_path=fake_pyproject)
+        cmd.version_file_path = fake_path
         cmd._update_version_file('22.04dev1')
 
         text = fake_path.write_text.call_args[0][0]
